@@ -71,6 +71,10 @@ void create_day_temperature_text(GHashTable *day, gchar *buffer, gboolean valid,
                                 gboolean for_combination_mode, gint button_number);
 void free_main_hash_table(GHashTable *table);
 void free_detaild_hash_table(GHashTable *table);
+void initial_gps_connect(void);
+void deinitial_gps_connect(void);
+void initial_gps_control(void);
+void deinitial_gps_control(void);
 #if defined OS2008 || defined OS2009 || defined APPLICATION || defined NONMAEMO
 void omweather_destroy(GtkObject *widget);
 #endif
